
.. mdinclude:: ../README.md
   :start-line: 2


.. toctree::
   :hidden:
   :maxdepth: 2

   readme
   core_concepts.ipynb
   download_maps.ipynb
   contribute
   acknowledgements

..
    Indices and tables
    ------------------

    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`

